from setuptools import find_packages, setup
setup(
    name='tweetpy',
    packages=find_packages(),
    version='0.1.4',
    description='Python package which to access the Tweet data without API',
    author='abdouhl',
    license='MIT',
)
